"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@tangential/core");
var DurationPickerFieldsState = (function () {
    function DurationPickerFieldsState(picker, unit) {
        this.picker = picker;
        this.unit = unit;
        this.selected = false;
    }
    Object.defineProperty(DurationPickerFieldsState.prototype, "label", {
        get: function () {
            return this.unit.label;
        },
        enumerable: true,
        configurable: true
    });
    DurationPickerFieldsState.prototype.canSelect = function () {
        var can;
        var count = this.picker.selectedCount();
        if (count >= 3) {
            can = false;
        }
        else if (count === 0) {
            can = true;
        }
        else {
            can = this.previous.selected || this.next.selected;
        }
        return can;
    };
    DurationPickerFieldsState.prototype.canDeselect = function () {
        /* If next and previous are selected then you cannot deselect this one. */
        return (!this.previous || !this.next || !this.previous.selected || !this.next.selected);
    };
    DurationPickerFieldsState.prototype.canToggleSelection = function () {
        return this.selected ? this.canDeselect() : this.canSelect();
    };
    Object.defineProperty(DurationPickerFieldsState.prototype, "value", {
        get: function () {
            var result;
            if (this.previous && this.previous.selected) {
                result = this.picker.duration.get(this.unit.momentKey);
            }
            else {
                result = this.picker.duration.as(this.unit.momentKey);
            }
            return Math.floor(result);
        },
        set: function (val) {
            if (val >= 0) {
                var prev = this.value;
                this.picker.duration.add(val - prev, this.unit.momentKey);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DurationPickerFieldsState.prototype, "separator", {
        get: function () {
            return this.unit.separatorSuffix;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DurationPickerFieldsState.prototype, "max", {
        get: function () {
            return (this.previous && this.previous.selected) ? this.unit.logicalMax : 9999;
        },
        enumerable: true,
        configurable: true
    });
    return DurationPickerFieldsState;
}());
exports.DurationPickerFieldsState = DurationPickerFieldsState;
var DurationPickerState = (function () {
    function DurationPickerState() {
        this.fields = [];
        this.fieldsByKey = {};
        this.fields = [
            new DurationPickerFieldsState(this, core_1.TimeUnits.day), new DurationPickerFieldsState(this, core_1.TimeUnits.h),
            new DurationPickerFieldsState(this, core_1.TimeUnits.min), new DurationPickerFieldsState(this, core_1.TimeUnits.s),
            new DurationPickerFieldsState(this, core_1.TimeUnits.ms),
        ];
        for (var i = 0; i < this.fields.length; i++) {
            var f = this.fields[i];
            f.next = this.fields[i + 1];
            f.previous = this.fields[i - 1];
            f.index = i;
            this.fieldsByKey[f.unit.unitKey] = f;
        }
    }
    DurationPickerState.prototype.selectedFields = function () {
        return this.fields.filter(function (f) { return f.selected; });
    };
    DurationPickerState.prototype.selectedCount = function () {
        return this.selectedFields().length;
    };
    DurationPickerState.prototype.setDuration = function (duration) {
        this.duration = duration;
    };
    DurationPickerState.prototype.select = function (unit) {
        this.fieldsByKey[unit.unitKey].selected = true;
    };
    Object.defineProperty(DurationPickerState.prototype, "millis", {
        get: function () {
            return this.duration.asMilliseconds();
        },
        enumerable: true,
        configurable: true
    });
    return DurationPickerState;
}());
exports.DurationPickerState = DurationPickerState;

//# sourceMappingURL=duration-picker-state.js.map
